/* custom map definitions */
var default_preview_path = "../../../Images/Maps/";

SMap.CONFIG["ZM10_ID"] = 
{
  zoom: [3, 16],
  label: "ZM10",
  title: "Základní mapa 10k",
  preview: default_preview_path + "ZM10.jpg",
  url: "",
  options: {prefetch: 0, tileSize: 256, gcDelay: (1000 * 3600 * 1)},
  copyright: {"1-": "ČÚZK"},
  projection: SMap.projUTM33,

  buildUrl: function(t /*tile*/)
  {
    var tileSize = this._options.tileSize;
    var tileType = "image/png8";  // jpeg/png/png8
  
    if      (t.zoom >= 13) var mapType = "GR_ZM10";
    else if (t.zoom >= 11) var mapType = "GR_ZM50";
    else if (t.zoom >= 9)  var mapType = "GR_MCR500";
    else if (t.zoom >= 0)  var mapType = "GR_CR4";
    
    if      (t.zoom >= 13) var mapDir = "WMS_ZM10_PUB";
    else if (t.zoom >= 11) var mapDir = "WMS_ZM50_PUB";
    else if (t.zoom >= 0)  var mapDir = "WMS_PREHLEDKY";

    function zoomAdjust(PP, zoom) {return (PP << (28 - zoom));}    
    var topLeft = SMap.Coords.prototype.toUTM33.apply({x: zoomAdjust(t.x, t.zoom), y: zoomAdjust(t.y, t.zoom)});
    var bottomRight = SMap.Coords.prototype.toUTM33.apply({x: zoomAdjust(t.x + tileSize / 256, t.zoom), y: zoomAdjust(t.y + tileSize / 256, t.zoom)});

    // http://geoportal-zm3.cuzk.cz/WMS_ZM10_PUB/service.svc/get?SERVICE=WMS&REQUEST=GetMap&VERSION=1.3.0&LAYERS=GR_ZM10&FORMAT=image%2Fpng8&WIDTH=256&HEIGHT=256&BBOX=458208,5548320,458464,5548576&CRS=EPSG%3A32633&STYLES=&TRANSPARENT=TRUE
    return ("http://geoportal-zm" + Math.floor(Math.random() * 4) + ".cuzk.cz" + "/" + mapDir + "/service.svc/get?"
      + "SERVICE=WMS&REQUEST=GetMap&VERSION=1.3.0" + "&LAYERS=" + mapType + "&FORMAT=" + encodeURIComponent(tileType) 
      + "&WIDTH=" + tileSize + "&HEIGHT=" + tileSize + "&BBOX=" + topLeft + "," + bottomRight 
      + "&CRS=" + encodeURIComponent("EPSG:32633") + "&STYLES=&TRANSPARENT=FALSE");  
  }
};

SMap.CONFIG["OSM_ID"] = 
{
  zoom: [2, 17],
  label: "OSM",
  title: "Open Street Maps",
  preview: default_preview_path + "OSM.png",
  url: "http://tile.openstreetmap.org/",
  options: {query: "{zoom}/{x}/{y}.png"},
  copyright: {"1-": "Open Street Maps"},
  projection: SMap.projMercator
};

SMap.CONFIG["OSMCyclo_ID"] = 
{
  zoom: [2, 17],
  label: "OSM Cyclo",
  title: "OpenCycleMap",
  preview: default_preview_path + "OSM Cyclo.png",
  url: "http://tile.opencyclemap.org/cycle/",
  options: {query: "{zoom}/{x}/{y}.png"},
  copyright: {"1-": "Open Street Maps"},
  projection: SMap.projMercator
};

SMap.CONFIG["GSatellite_ID"] = 
{
  zoom: [2, 20],
  label: "Google Satellite",
  title: "Google Satellite Maps",
  preview: default_preview_path + "Google Satellite.jpg",
  
  // note: version (v=???) sometimes changes, so fix it from time to time
  url: "http://khm1.google.com/kh/v=123&",
  options: {query: "x={x}\&y={y}\&z={zoom}"},
  copyright: {"1-": "Google"},
  projection: SMap.projMercator
};

SMap.CONFIG["GMaps_ID"] = 
{
  zoom: [2, 17],
  label: "Google Maps",
  title: "Google Maps",
  preview: default_preview_path + "Google Maps.jpg",
  url: "http://mt2.google.com/vt/hl=cs&",
  options: {query: "x={x}&y={y}&z={zoom}"},
  copyright: {"1-": "Google"},
  projection: SMap.projMercator
};

SMap.CONFIG["GHybrid_ID"] = 
{
  // note: version (h@???) sometimes changes, so fix it from time to time
  // use m@ instead of h@ to display satellite maps
  url: "http://mt2.google.com/vt/lyrs=h@206000000&hl=cs&",
  options: {query: "x={x}&y={y}&z={zoom}", animTime: 0, fadeTime: 0, prefetch: 0, alpha: true},
  copyright: {"1-": "Google"},
  projection: SMap.projMercator
};

SMap.CONFIG["GStreetView_ID"] = 
{
  // lmc:photos_outside_streetview_134,svv --> street view + images
  // lmc:panoramio,svv --> street view + panoramio images
  // lmc:,svv --> street view only
  url: "http://mt0.google.com/mapslt?lyrs=lmc:,svv&w=256&h=256&hl=cs&style=40,18&",
  options: {query: "x={x}&y={y}&z={zoom}", animTime: 0, fadeTime: 0, prefetch: 0, alpha: true},
  copyright: {"1-": "Google"},
  projection: SMap.projMercator
};

SMap.CONFIG["FreemapSK_ID"] = 
{
  zoom: [5, 16],
  label: "Freemap SK",
  title: "Freemap.sk",
  preview: default_preview_path + "FreemapSK.png",
  
  // a. --> can be a/b/c/d
  // T - turistická, A - autoatlas, C - cyklo, K - běžkařská
  // url for K: http://t4.freemap.sk/K/
  
  url: "http://a.freemap.sk/data/layers/presets/T/",  
  options: {query: "{zoom}/{x}/{y}.jpeg"},
  copyright: {"1-": "Freemap.sk"},
  projection: SMap.projMercator
};
